@@ -1,7 +1,8 @@
 from django.contrib import admin
 
-from models import Article, Tag
+from models import Article, Tag, Comment
 
 
 admin.site.register(Article)
-admin.site.register(Tag)
\ No newline at end of file
+admin.site.register(Tag)
+admin.site.register(Comment)
\ No newline at end of file
