@@ -4,5 +4,8 @@ import settings
 
 def base(request):
     tags = Tag.objects.order_by("name")
-    base_labels = {"header": settings.SIMPLEBLOG_HEADER, }
+    base_labels = {
+        "header": settings.SIMPLEBLOG_HEADER,
+        "domain": settings.SIMPLEBLOG_DOMAIN,
+    }
     return {"base_tags": tags, "base_labels": base_labels, }
\ No newline at end of file
