@@ -31,4 +31,21 @@ class Article(models.Model):
     def save(self):
         if not self.pk:
             self.url_key = slugify(self.title)
-        return super(Article, self).save()
\ No newline at end of file
+        return super(Article, self).save()
+
+    def get_comments(self):
+        return self.comment_set.order_by("pk")
+
+class Comment(models.Model):
+    article = models.ForeignKey(Article)
+    created_at = models.DateField(auto_now_add=True)
+
+    author_name = models.CharField(max_length=64)
+    author_email = models.CharField(max_length=64)
+
+    title = models.CharField(max_length=255)
+    text = models.TextField(null=True, blank=True)
+
+    def __unicode__(self):
+        return u"%s %i %s" % (self.title[:30], self.pk, self.article.title)
+    
\ No newline at end of file
